*Version: 1.0, Date: 06.11.2024*
 
## __The additive manufactured twin-screw granulator for lab-scale research__

__Authors: Plath, Timo¹*; Lansink, Matthijs¹; Fokkink, Harm¹; Hermans, Joep¹; Imankarijo, Siddieq¹; Brinks, Thijs¹; Van de Veen, Bas¹; Barlo, Rik¹; Gali, Prudhvi¹; Weinhart, Thomas¹__

¹ Thermal and Fluid Engineering (ET) | University of Twente | P.O. Box 217, 7500 AE Enschede, The Netherlands |  
\* Corresponding author: Plath, Timo; t.plath@utwente.nl

***General Introduction***

This dataset contains all CAD files to construct your own twin-screw granulator (TSG) for lab-scale research. Furthermore, it contains fully working copies of a python script (Version 3.10.12), data (measurement data for roughness, accuracy and water resistance) and code to plot the figures of the study, verify integrity and make this dataset reusable according to the FAIR principles.
This research was funded by NWO VIDI grant 16604, *“Virtual Prototyping of Particulate Processes”*.

***Abstract***

Twin-screw wet granulation has emerged as a promising solution for continuous manufacturing in the pharmaceutical sector, characterised by its flexibility and ability to produce granules with improved quality and homogeneity. However, challenges related to product formulations and twin-screw geometry affect granule properties, making lab-scale experiments costly. The study underlying this dataset explores the feasibility of using additive manufacturing to develop a functional and transparent twin-screw granulator for lab-scale research. Various printing methods, namely selective laser sintering, fused deposition modelling, and stereolithography, were evaluated for their manufacturing accuracy and surface roughness. An additive manufacturable twin-screw granulator design is proposed based on the Pharma 11 by Thermo Scientific Fisher. The granulator was successfully printed and tested in dry granulation experiments with sesame and canihua, revealing challenges such as gear slip. While the prototype serves as a proof of concept, some optimisation opportunities remain. This dataset contains all CAD files to construct your own twin-screw granulator for lab-scale research. Furthermore, it contains fully working copies of python tools and data (roughness data, measurement data) to plot the figures of the study, verify integrity and make this dataset reusable according to the FAIR principles.

***Description of the data in this software set***

Wherever possible, all data is provided in established open file formats (.csv, .md, .eps, .jpg, .mp4, .py, .STEP, .STL and .txt). Non-open formats include Solidworks files (.SLDASM, .SLDPRT), Excel files (.xlsx) and keyence profilometry files (.vk3) to enable easy access if the software is available. The surface roughness data was analysed to plot figures using VK Analyzer Version 2.5.0.1 by Keyence, but can also be analysed using the open-source alternative Gwyddion (http://gwyddion.net/). We refer to the paper for variable definition and names in generated figures from the software. Please do not move files or folders, as the scripts are fully functional in the current state of this dataset.
The python version tested *3.10.12*. The python script is commented to make it self-explanatory.


***Detailed description of the data and folder structure***

Subfolders are named intuitively and the data inside subfolders should be described by the subfolders name. See folder structure of this dataset below

```
Dataset/
├── AccuracyMeasurements.csv 				: Spreadsheet file with the accuracy measurement data from different additive manufacturing methods
├── AccuracyMeasurements.xlsx				: Spreadsheet Excel file with the accuracy measurement data from different additive manufacturing methods
├── CELength.eps					: Image file for deviation_plot.py showing the measured length of a conveying element
├── deviation_plot.py					: Python file to plot the deviation plot for different additive manufacturing methods and measurements
├── EllipseWidthLarge.eps				: Image file for deviation_plot.py showing the measured largest width
├── EllipseWidthSmall.eps				: Image file for deviation_plot.py showing the measured smallest width
├── HexagonalWidth.eps					: Image file for deviation_plot.py showing the measured hexagonal face to face width
├── KELength.eps					: Image file for deviation_plot.py showing the measured length of a kneading element
├── ProofOfConcept.mp4					: Video file showcasing the proof of concept with canihua seeds
├── WaterResistanceMeasurements.csv			: Spreadsheet file with experiments about water resistance/absorption of the different parts
├── WaterResistanceMeasurements.xlsx			: Spreadsheet Excel file with experiments about water resistance/absorption of the different parts		
├── CAD
│   ├── Assembly.SLDASM					: Solidworks assembly file containing an assembly of all screw elements
│   ├── Assembly.STEP					: STEP ap214 file containing an assembly of all screw elements
│   ├── AssemblyAxle.SLDASM				: Solidworks assembly file containing an assembly of all screw elements on the main axles
│   ├── AssemblyAxle.STEP				: STEP ap214 file containing an assembly of all screw elements on the main axles
│   ├── AssemblyGears.SLDASM				: Solidworks assembly file containing an assembly of the driving and driven gears
│   ├── AssemblyGears.STEP				: STEP ap214 file containing an assembly of the driving and driven gears
│   ├── AssemblyKneading.SLDASM				: Solidworks assembly file containing an assembly of multiple kneading elements
│   ├── AssemblyKneading.STEP				: STEP ap214 file containing an assembly of all multiple kneading elements
│   ├── ConveyingElement.SLDPRT				: Solidworks part file containing the conveying screw element
│   ├── ConveyingElement.STEP				: STEP ap214 file containing the conveying screw element
│   ├── ConveyingElement.STL				: Geometry STL file for additive manufacturing containing the conveying screw element
│   ├── DFSElement.SLDPRT				: Solidworks part file containing the distributive feed screw element
│   ├── DFSElement.STEP					: STEP ap214 file containing the distributive feed screw element
│   ├── DFSElement.STL					: Geometry STL file for additive manufacturing containing the distributive feed screw element
│   ├── DrivenGear1.SLDPRT				: Solidworks part file containing the first of the driven gears
│   ├── DrivenGear1.STEP				: STEP ap214 file containing the first of the driven gears
│   ├── DrivenGear1.STL					: Geometry STL file for additive manufacturing containing the first of the driven gears
│   ├── DrivenGear2.SLDPRT				: Solidworks part file containing the second of the driven gears (rotated by a certain degree)
│   ├── DrivenGear2.STEP				: STEP ap214 file containing the second of the driven gears (rotated by a certain degree)
│   ├── DrivenGear2.STL					: Geometry STL file for additive manufacturing containing the second of the driven gears (rotated by a certain degree)
│   ├── DrivingGear.SLDPRT				: Solidworks part file containing the driving gear
│   ├── DrivingGear.STEP				: STEP ap214 file containing the driving gear
│   ├── DrivingGear.STL					: Geometry STL file for additive manufacturing containing the driving gear
│   ├── HexagonalAxle.SLDPRT				: Solidworks part file containing the hexagonal main axle
│   ├── HexagonalAxle.STEP				: STEP ap214 file containing the hexagonal main axle
│   ├── HexagonalAxle.STL				: Geometry STL file for additive manufacturing containing the hexagonal main axle
│   ├── HexagonalSpacer.SLDPRT				: Solidworks part file containing the hexagonal spacers which can be cut to length
│   ├── HexagonalSpacer.STEP				: STEP ap214 file containing the hexagonal spacers which can be cut to length
│   ├── HexagonalSpacer.STL				: Geometry STL file for additive manufacturing containing the hexagonal spacers which can be cut to length
│   ├── KneadingElement.SLDPRT				: Solidworks part file containing the kneading screw element
│   ├── KneadingElement.STEP				: STEP ap214 file containing the kneading screw element
│   ├── KneadingElement.STL				: Geometry STL file for additive manufacturing containing the kneading screw element
│   ├── TSGAssembly.SLDASM				: Solidworks assembly file containing an assembly of all housing elements
│   ├── TSGAssembly.STEP				: STEP ap214 file containing an assembly of all housing elements
│   ├── TSGBottom.SLDPRT				: Solidworks part file containing the bottom part of the housing
│   ├── TSGBottom.STEP					: STEP ap214 file containing the bottom part of the housing
│   ├── TSGBottom.STL					: Geometry STL file for additive manufacturing containing the bottom part of the housing
│   ├── TSGCrankHandle.SLDPRT				: Solidworks part file containing the crank handle to manually run the granulator
│   ├── TSGCrankHandle.STEP				: STEP ap214 file containing the crank handle to manually run the granulator
│   ├── TSGCrankHandle.STL				: Geometry STL for additive manufacturing containing the crank handle to manually run the granulator
│   ├── TSGTop.SLDPRT					: Solidworks part file containing the top part of the housing
│   ├── TSGTop.STEP					: STEP ap214 file containing the top part of the housing
│   ├── TSGTop.STL					: Geometry STL file for additive manufacturing containing the top part of the housing
│   ├── TSGTopBack.SLDPRT				: Solidworks part file containing the small top part housing the gears
│   ├── TSGTopBack.STEP					: STEP ap214 file containing the small top part housing the gears
│   └── TSGTopBack.STL					: Geometry STL file for additive manufacturing containing the small top part housing the gears
├── Figures
│   ├── AMTSGExplosionView.eps				: Figure showing an explosion view of the additive manufactured twin-screw granulator
│   ├── AMTSGSchematic.eps				: Figure showing the schematic view of the additive manufactured twin-screw granulator
│   ├── AMTSGSideView.eps				: Figure showing the sideview of the additive manufactured twin-screw granulator
│   ├── AMTSGTransparent.jpg				: Figure showing the transparency feature of the additive manufactured twin-screw granulator
│   ├── Accuracy.eps					: Figure showing the accuracy deviations from the original CAD models
│   ├── Canihua.eps					: Figure showing multiple pictures where Canihua (similar to Quinoa) is conveyed in the granulator
│   ├── GearsSchematic.eps				: Figure showing the schematic setup of the driving and driven gears
│   ├── TSGSchematic.eps				: Figure showing the schematic view of a twin-screw granulator
│   └── surfaceMeasurements.eps				: Figure showing the surface measurement sample points on different material samples
└── RoughnessMeasurements
    ├── PLA.vk3						: Keyence VK3 profilometry data file containing the FDM (PLA) surface measurement data from laser microscopy (VK 9700) 
    ├── SLA.vk3						: Keyence VK3 profilometry data file containing the SLA (Tough resin V5) surface measurement data from laser microscopy (VK 9700)
    └── SLS.vk3						: Keyence VK3 profilometry data file containing the SLS (Nylon PA2200) surface measurement data from laser microscopy (VK 9700)	
```